pub struct Schema { /* private fields */ }Expand description
Schema defining document structure
Implementations
Sourceimpl Schema
impl Schema
pub fn builder() -> SchemaBuilder
pub fn get_field(&self, name: &str) -> Option<Field>
pub fn get_field_entry(&self, field: Field) -> Option<&FieldEntry>
Sourcepub fn tokenizer_hint_field(&self, field: Field) -> Option<Field>
pub fn tokenizer_hint_field(&self, field: Field) -> Option<Field>
Field whose values hint the dynamic tokenizer of field
(text<lex(by: <hint field>, ...)>), if any.
Sourcepub fn with_vector_index_alter(
&self,
field: Field,
alter: VectorIndexAlter,
) -> Result<Self, String>
pub fn with_vector_index_alter( &self, field: Field, alter: VectorIndexAlter, ) -> Result<Self, String>
Clone this schema with one vector field’s ANN parameters replaced. Field type, dimension, and storage quantization are immutable.
pub fn get_field_name(&self, field: Field) -> Option<&str>
pub fn fields(&self) -> impl Iterator<Item = (Field, &FieldEntry)>
pub fn num_fields(&self) -> usize
Sourcepub fn has_reorder_fields(&self) -> bool
pub fn has_reorder_fields(&self) -> bool
Whether any field has the reorder attribute set.
Used by the background optimizer to determine which indexes need BP reordering.
Sourcepub fn reorder_on_merge(&self) -> bool
pub fn reorder_on_merge(&self) -> bool
Whether merges BP-reorder reorder-attributed BMP fields while writing
the merged segment (index-level SDL option reorder_on_merge: true).
Sourcepub fn index_label(&self) -> &str
pub fn index_label(&self) -> &str
Index name for metric labels (“unknown” when not set — pre-existing metadata or programmatic schemas without a name).
Sourcepub fn set_index_name(&mut self, name: impl Into<String>)
pub fn set_index_name(&mut self, name: impl Into<String>)
Set the index name used as the metrics index label.
Sourcepub fn default_fields(&self) -> &[Field]
pub fn default_fields(&self) -> &[Field]
Get the default fields for query parsing
Sourcepub fn set_default_fields(&mut self, fields: Vec<Field>)
pub fn set_default_fields(&mut self, fields: Vec<Field>)
Set default fields (used by builder)
Sourcepub fn query_routers(&self) -> &[QueryRouterRule]
pub fn query_routers(&self) -> &[QueryRouterRule]
Get the query router rules
Sourcepub fn set_query_routers(&mut self, rules: Vec<QueryRouterRule>)
pub fn set_query_routers(&mut self, rules: Vec<QueryRouterRule>)
Set query router rules
Sourcepub fn primary_field(&self) -> Option<Field>
pub fn primary_field(&self) -> Option<Field>
Get the primary key field, if one is defined