pub struct SparseTermQueryInfo {
pub field: Field,
pub dim_id: u32,
pub weight: f32,
pub candidate: bool,
pub heap_factor: f32,
pub combiner: MultiValueCombiner,
pub over_fetch_factor: f32,
pub lsp_gamma: Option<usize>,
}Expand description
Info for MaxScore-optimizable sparse term queries
Fields
field: FieldSparse vector field
dim_id: u32Dimension ID in the sparse vector
weight: f32Query weight for this dimension
candidate: boolWhether this term participates in candidate generation. BMP/LSP uses the pruned subset for maximum-grid traversal, then scores candidates with every term retained in this decomposition.
heap_factor: f32MaxScore heap factor (1.0 = exact, lower = approximate)
combiner: MultiValueCombinerMulti-value combiner for ordinal deduplication
over_fetch_factor: f32Multiplier on executor limit to compensate for ordinal deduplication (1.0 = exact, 2.0 = fetch 2x then combine down)
lsp_gamma: Option<usize>LSP/0 γ. None is depth-derived; Some(0) is exhaustive.