pub struct ScannConfig {
pub dimension: u32,
pub tree_levels: u8,
pub num_leaves: u32,
pub encoding: ScannEncoding,
}Expand description
Index-scoped ScaNN training and layout configuration.
Fields
dimension: u32Float dimensions for AH, bit dimensions for binary Hamming.
tree_levels: u8Configurable number of routing centroid levels.
num_leaves: u32Number of terminal leaves shared by every segment.
encoding: ScannEncodingImplementations
Sourceimpl ScannConfig
impl ScannConfig
pub fn validate(&self) -> ScannResult<()>
Sourcepub fn minimum_training_sample(&self) -> ScannResult<u64>
pub fn minimum_training_sample(&self) -> ScannResult<u64>
Minimum viable sample. A trainer may reduce the desired sample under a memory budget only while retaining at least this many rows.
Sourcepub fn desired_training_sample(&self, observed_vectors: u64) -> ScannResult<u64>
pub fn desired_training_sample(&self, observed_vectors: u64) -> ScannResult<u64>
Recall-oriented sample target from the fresh ScaNN builder. The target is capped by the observed corpus, but never silently changes geometry.
Sourcepub fn effective_training_threshold(&self) -> ScannResult<u64>
pub fn effective_training_threshold(&self) -> ScannResult<u64>
Minimum corpus size at which a requested partition geometry may train. Before this threshold, serving must use the exact fallback.
pub fn training_state( &self, observed_vectors: u64, ) -> ScannResult<ScannTrainingState>