pub struct EagerParallelStoreWriter<'a> { /* private fields */ }Expand description
Parallel document store writer - compresses blocks immediately when queued
Spawns compression tasks as soon as blocks are ready, overlapping document ingestion with compression to reduce total indexing time.
Uses background threads to compress blocks while the main thread continues accepting documents.
Implementations
Sourceimpl<'a> EagerParallelStoreWriter<'a>
impl<'a> EagerParallelStoreWriter<'a>
Sourcepub fn new(writer: &'a mut dyn Write, _num_threads: usize) -> Self
pub fn new(writer: &'a mut dyn Write, _num_threads: usize) -> Self
Create a new eager parallel store writer
Sourcepub fn with_compression_level(
writer: &'a mut dyn Write,
_num_threads: usize,
compression_level: CompressionLevel,
) -> Self
pub fn with_compression_level( writer: &'a mut dyn Write, _num_threads: usize, compression_level: CompressionLevel, ) -> Self
Create with specific compression level
Sourcepub fn with_dict(
writer: &'a mut dyn Write,
dict: CompressionDict,
_num_threads: usize,
) -> Self
pub fn with_dict( writer: &'a mut dyn Write, dict: CompressionDict, _num_threads: usize, ) -> Self
Create with dictionary
Sourcepub fn with_dict_and_level(
writer: &'a mut dyn Write,
dict: CompressionDict,
_num_threads: usize,
compression_level: CompressionLevel,
) -> Self
pub fn with_dict_and_level( writer: &'a mut dyn Write, dict: CompressionDict, _num_threads: usize, compression_level: CompressionLevel, ) -> Self
Create with dictionary and specific compression level
pub fn store(&mut self, doc: &Document, schema: &Schema) -> Result<DocId>
Sourcepub fn store_raw(&mut self, doc_bytes: &[u8]) -> Result<DocId>
pub fn store_raw(&mut self, doc_bytes: &[u8]) -> Result<DocId>
Store pre-serialized document bytes directly (avoids deserialize+reserialize roundtrip).
pub fn finish(self) -> Result<u32>